http://localhost
This documents the API calls that can be made to query and manage instance custom links
Collection of instance-custom-link items.
Return a list of instance custom links
GET /instance-custom-linksA query expressed as a CQL string (see dev.folio.org/reference/glossary#cql) using valid searchable fields. The first example below shows the general form of a full CQL query, but those fields might not be relevant in this context.
with valid searchable fields
Example:
(username=="ab*" or personal.firstName=="ab*" or personal.lastName=="ab*") and active=="true" sortby personal.lastName personal.firstName barcode
name=aaa
How to calculate the totalRecords property. "exact" for the correct number, "estimated" for an estimation, "auto" to automatically select "exact" or "estimated", "none" for suppressing the totalRecords property. For details see https://github.com/folio-org/raml-module-builder#estimated-totalrecords
Example:
noneSkip over a number of elements by specifying an offset value for the query
Example:
0Limit the number of elements returned in the response. Using limit=0 will return totalRecords with the exact value. For details about totalRecords see https://github.com/folio-org/raml-module-builder#estimated-totalrecords
Example:
10Returns a list of instance-custom-link items
Media type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"description": "A collection of instance custom links",
"javaType": "org.folio.rest.jaxrs.model.InstanceCustomLinks",
"type": "object",
"properties": {
"instanceCustomLinks": {
"description": "List of instance custom links",
"id": "instanceCustomLinks",
"type": "array",
"items": {
"type": "object",
"$schema": "http://json-schema.org/draft-04/schema#",
"description": "An instance custom link",
"javaType": "org.folio.rest.jaxrs.model.InstanceCustomLink",
"properties": {
"id": {
"type": "string",
"description": "The unique ID of the instance custom link; UUID",
"$schema": "http://json-schema.org/draft-04/schema#",
"pattern": "^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$"
},
"name": {
"type": "string",
"description": "Name of the instance custom link",
"maxLength": 150
},
"linkText": {
"type": "string",
"description": "Text to display when rendering the instance custom link",
"maxLength": 40
},
"link": {
"type": "string",
"description": "The base URL including scheme and host for rendering the instance custom link",
"maxLength": 1000
},
"show": {
"type": "boolean",
"description": "Whether to show this instance custom link"
},
"source": {
"type": "string",
"enum": [
"local",
"consortium"
],
"description": "The instance custom link source"
},
"metadata": {
"type": "object",
"readonly": true,
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "metadata.schema",
"title": "Metadata Schema",
"description": "Metadata about creation and changes to records, provided by the server (client should not provide)",
"properties": {
"createdDate": {
"description": "Date and time when the record was created",
"type": "string",
"format": "date-time"
},
"createdByUserId": {
"description": "ID of the user who created the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"createdByUsername": {
"description": "Username of the user who created the record (when available)",
"type": "string"
},
"updatedDate": {
"description": "Date and time when the record was last updated",
"type": "string",
"format": "date-time"
},
"updatedByUserId": {
"description": "ID of the user who last updated the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"updatedByUsername": {
"description": "Username of the user who last updated the record (when available)",
"type": "string"
}
},
"additionalProperties": false,
"required": [
"createdDate"
]
}
},
"required": [
"name",
"linkText",
"link",
"show",
"source"
]
}
},
"totalRecords": {
"description": "Estimated or exact total number of records",
"type": "integer"
}
},
"required": [
"instanceCustomLinks",
"totalRecords"
]
}Example:
{
"instanceCustomLinks": [
{
"id": "a3300f00-1d30-440d-a475-a5c8fad7ba7e",
"name": "OPAC",
"linkText": "Locate",
"link": "https://www.locate.library.com/items/{UUID}.html",
"show": true
},
{
"id": "a63a2d8c-22a4-4bfc-9d8d-5ade3b5154fa",
"name": "archival",
"linkText": "Old OPAC",
"link": "https://old-opac.library.com",
"show": false
}
],
"totalRecords": 2
}Bad request, e.g. malformed request body or query parameter. Details of the error (e.g. name of the parameter or line/character number with malformed data) provided in the response.
Media type: text/plain
Type: any
Example:
unable to list instance-custom-links -- malformed parameter 'query', syntax error at column 6Not authorized to perform requested action
Media type: text/plain
Type: any
Example:
unable to list instance-custom-links -- unauthorizedInternal server error, e.g. due to misconfiguration
Media type: text/plain
Type: any
Example:
internal server error, contact administratorCreate a new instance custom link
POST /instance-custom-linksMedia type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"description": "An instance custom link",
"javaType": "org.folio.rest.jaxrs.model.InstanceCustomLink",
"type": "object",
"properties": {
"id": {
"type": "string",
"description": "The unique ID of the instance custom link; UUID",
"$schema": "http://json-schema.org/draft-04/schema#",
"pattern": "^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$"
},
"name": {
"type": "string",
"description": "Name of the instance custom link",
"maxLength": 150
},
"linkText": {
"type": "string",
"description": "Text to display when rendering the instance custom link",
"maxLength": 40
},
"link": {
"type": "string",
"description": "The base URL including scheme and host for rendering the instance custom link",
"maxLength": 1000
},
"show": {
"type": "boolean",
"description": "Whether to show this instance custom link"
},
"source": {
"type": "string",
"enum": [
"local",
"consortium"
],
"description": "The instance custom link source"
},
"metadata": {
"type": "object",
"readonly": true,
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "metadata.schema",
"title": "Metadata Schema",
"description": "Metadata about creation and changes to records, provided by the server (client should not provide)",
"properties": {
"createdDate": {
"description": "Date and time when the record was created",
"type": "string",
"format": "date-time"
},
"createdByUserId": {
"description": "ID of the user who created the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"createdByUsername": {
"description": "Username of the user who created the record (when available)",
"type": "string"
},
"updatedDate": {
"description": "Date and time when the record was last updated",
"type": "string",
"format": "date-time"
},
"updatedByUserId": {
"description": "ID of the user who last updated the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"updatedByUsername": {
"description": "Username of the user who last updated the record (when available)",
"type": "string"
}
},
"additionalProperties": false,
"required": [
"createdDate"
]
}
},
"required": [
"name",
"linkText",
"link",
"show",
"source"
]
}Example:
{
"id": "a3300f00-1d30-440d-a475-a5c8fad7ba7e",
"name": "OPAC",
"linkText": "Locate",
"link": "https://www.locate.library.com/items/{UUID}.html",
"show": true
}Returns a newly created item, with server-controlled fields like 'id' populated
URI to the created instance-custom-link item
Media type: application/json
Type: any
Example:
{
"id": "a3300f00-1d30-440d-a475-a5c8fad7ba7e",
"name": "OPAC",
"linkText": "Locate",
"link": "https://www.locate.library.com/items/{UUID}.html",
"show": true
}Bad request, e.g. malformed request body or query parameter. Details of the error (e.g. name of the parameter or line/character number with malformed data) provided in the response.
Media type: text/plain
Type: any
Example:
"unable to add instance-custom-link -- malformed JSON at 13:3"
Not authorized to perform requested action
Media type: text/plain
Type: any
Example:
unable to create instance-custom-links -- unauthorizedValidation errors
Media type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "errors.schema",
"description": "A set of errors",
"type": "object",
"properties": {
"errors": {
"description": "List of errors",
"id": "errors",
"type": "array",
"items": {
"type": "object",
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "error.schema",
"description": "An error",
"properties": {
"message": {
"type": "string",
"description": "Error message text"
},
"type": {
"type": "string",
"description": "Error message type"
},
"code": {
"type": "string",
"description": "Error message code"
},
"parameters": {
"description": "Error message parameters",
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "parameters.schema",
"type": "array",
"items": {
"type": "object",
"properties": {
"key": {
"type": "string"
},
"value": {
"type": "string"
}
}
}
}
},
"required": [
"message"
]
}
},
"total_records": {
"description": "Total number of errors",
"type": "integer"
}
}
}Example:
{
"errors": [
{
"message": "may not be null",
"type": "1",
"code": "-1",
"parameters": [
{
"key": "moduleTo",
"value": "null"
}
]
}
]
}
Internal server error, e.g. due to misconfiguration
Media type: text/plain
Type: any
Example:
Internal server error, contact administratorUpdate a instance custom link
PUT /instance-custom-links/{id}Media type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"description": "An instance custom link",
"javaType": "org.folio.rest.jaxrs.model.InstanceCustomLink",
"type": "object",
"properties": {
"id": {
"type": "string",
"description": "The unique ID of the instance custom link; UUID",
"$schema": "http://json-schema.org/draft-04/schema#",
"pattern": "^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$"
},
"name": {
"type": "string",
"description": "Name of the instance custom link",
"maxLength": 150
},
"linkText": {
"type": "string",
"description": "Text to display when rendering the instance custom link",
"maxLength": 40
},
"link": {
"type": "string",
"description": "The base URL including scheme and host for rendering the instance custom link",
"maxLength": 1000
},
"show": {
"type": "boolean",
"description": "Whether to show this instance custom link"
},
"source": {
"type": "string",
"enum": [
"local",
"consortium"
],
"description": "The instance custom link source"
},
"metadata": {
"type": "object",
"readonly": true,
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "metadata.schema",
"title": "Metadata Schema",
"description": "Metadata about creation and changes to records, provided by the server (client should not provide)",
"properties": {
"createdDate": {
"description": "Date and time when the record was created",
"type": "string",
"format": "date-time"
},
"createdByUserId": {
"description": "ID of the user who created the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"createdByUsername": {
"description": "Username of the user who created the record (when available)",
"type": "string"
},
"updatedDate": {
"description": "Date and time when the record was last updated",
"type": "string",
"format": "date-time"
},
"updatedByUserId": {
"description": "ID of the user who last updated the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"updatedByUsername": {
"description": "Username of the user who last updated the record (when available)",
"type": "string"
}
},
"additionalProperties": false,
"required": [
"createdDate"
]
}
},
"required": [
"name",
"linkText",
"link",
"show",
"source"
]
}Example:
{
"id": "a3300f00-1d30-440d-a475-a5c8fad7ba7e",
"name": "OPAC",
"linkText": "Locate",
"link": "https://www.locate.library.com/items/{UUID}.html",
"show": true
}Item successfully updated
Bad request, e.g. malformed request body or query parameter. Details of the error (e.g. name of the parameter or line/character number with malformed data) provided in the response.
Media type: text/plain
Type: any
Example:
"unable to update instance-custom-link -- malformed JSON at 13:4"
Item with a given ID not found
Media type: text/plain
Type: any
Example:
"instance-custom-link not found"
Optimistic locking version conflict
Media type: text/plain
Type: any
Example:
version conflictValidation error
Media type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "errors.schema",
"description": "A set of errors",
"type": "object",
"properties": {
"errors": {
"description": "List of errors",
"id": "errors",
"type": "array",
"items": {
"type": "object",
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "error.schema",
"description": "An error",
"properties": {
"message": {
"type": "string",
"description": "Error message text"
},
"type": {
"type": "string",
"description": "Error message type"
},
"code": {
"type": "string",
"description": "Error message code"
},
"parameters": {
"description": "Error message parameters",
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "parameters.schema",
"type": "array",
"items": {
"type": "object",
"properties": {
"key": {
"type": "string"
},
"value": {
"type": "string"
}
}
}
}
},
"required": [
"message"
]
}
},
"total_records": {
"description": "Total number of errors",
"type": "integer"
}
}
}Example:
{
"errors": [
{
"message": "may not be null",
"type": "1",
"code": "-1",
"parameters": [
{
"key": "moduleTo",
"value": "null"
}
]
}
]
}
Internal server error, e.g. due to misconfiguration
Media type: text/plain
Type: any
Example:
internal server error, contact administratorRetrieve instance-custom-link item with given {instance-custom-linkId}
GET /instance-custom-links/{id}Returns item with a given ID
Media type: application/json
Type: json
Content:
{
"$schema": "http://json-schema.org/draft-04/schema#",
"description": "An instance custom link",
"javaType": "org.folio.rest.jaxrs.model.InstanceCustomLink",
"type": "object",
"properties": {
"id": {
"type": "string",
"description": "The unique ID of the instance custom link; UUID",
"$schema": "http://json-schema.org/draft-04/schema#",
"pattern": "^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$"
},
"name": {
"type": "string",
"description": "Name of the instance custom link",
"maxLength": 150
},
"linkText": {
"type": "string",
"description": "Text to display when rendering the instance custom link",
"maxLength": 40
},
"link": {
"type": "string",
"description": "The base URL including scheme and host for rendering the instance custom link",
"maxLength": 1000
},
"show": {
"type": "boolean",
"description": "Whether to show this instance custom link"
},
"source": {
"type": "string",
"enum": [
"local",
"consortium"
],
"description": "The instance custom link source"
},
"metadata": {
"type": "object",
"readonly": true,
"$schema": "http://json-schema.org/draft-04/schema#",
"id": "metadata.schema",
"title": "Metadata Schema",
"description": "Metadata about creation and changes to records, provided by the server (client should not provide)",
"properties": {
"createdDate": {
"description": "Date and time when the record was created",
"type": "string",
"format": "date-time"
},
"createdByUserId": {
"description": "ID of the user who created the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"createdByUsername": {
"description": "Username of the user who created the record (when available)",
"type": "string"
},
"updatedDate": {
"description": "Date and time when the record was last updated",
"type": "string",
"format": "date-time"
},
"updatedByUserId": {
"description": "ID of the user who last updated the record (when available)",
"type": "string",
"pattern": "^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
},
"updatedByUsername": {
"description": "Username of the user who last updated the record (when available)",
"type": "string"
}
},
"additionalProperties": false,
"required": [
"createdDate"
]
}
},
"required": [
"name",
"linkText",
"link",
"show",
"source"
]
}Example:
{
"id": "a3300f00-1d30-440d-a475-a5c8fad7ba7e",
"name": "OPAC",
"linkText": "Locate",
"link": "https://www.locate.library.com/items/{UUID}.html",
"show": true
}Item with a given ID not found
Media type: text/plain
Type: any
Example:
"instance-custom-link not found"
Internal server error, e.g. due to misconfiguration
Media type: text/plain
Type: any
Example:
internal server error, contact administratorDelete instance-custom-link item with given {instance-custom-linkId}
DELETE /instance-custom-links/{id}Item deleted successfully
Bad request, e.g. malformed request body or query parameter. Details of the error (e.g. name of the parameter or line/character number with malformed data) provided in the response.
Media type: text/plain
Type: any
Example:
"unable to delete instance-custom-link -- constraint violation"
Item with a given ID not found
Media type: text/plain
Type: any
Example:
"instance-custom-link not found"
Internal server error, e.g. due to misconfiguration
Media type: text/plain
Type: any
Example:
Internal server error, contact administrator